# Clinica

Welcome to the [**Clinica**](http://clinica.run) software! All the information can be found on the [wiki](http://clinica.run/doc) section!

[![pipeline status](https://gitlab.icm-institute.org/aramislab/clinica/badges/%{default_branch}/pipeline.svg)](https://gitlab.icm-institute.org/aramislab/clinica/commits/dev)
[![conda install](https://anaconda.org/aramislab/clinica/badges/installer/conda.svg)](http://clinica.run/doc/Installation/)
[![platform](https://anaconda.org/aramislab/clinica/badges/platforms.svg)](http://clinica.run/doc/Installation/)
[![license](https://anaconda.org/aramislab/clinica/badges/license.svg)](http://clinica.run/doc/Installation/)
